# Telemetria

Shows apoapsis and periapsis on main KSP screen. Also provides key binding for Prograde, Retrograde, SAS:Surface/SAS:Orbit, and Warp to Next Maneuver. Optionally shows Ascent Guidance.  
  
*Quick List of Features:*

1) Displays Ap and Pe details on the main (Ship) screen

2) Provides keyboard switching for Prograde/Retrograde, SAS:Surface/SAS:Orbit, and "Warp to Next Maneuver"

3) Provides Ascent Guidance for optimal launches, and Radar Altimeter when landing

4) A goal of being as small and simple as possible.


### LICENSE:
Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International (CC BY-NC-SA 4.0)


### CHANGELOG:
  - 0.1: Initial Build.
  - 0.2: Add Ascent Guidance, add new display options, minor fixes
  - 0.3: Fixed error with Radar Altimeter reading incorrectly over water
  - 0.4: Updated persistence logic when switching scenes and vessels
  - 0.5: Added Vessel Latitude readout, plus time to Ascending/Descending node for easier inclination changes
  - 0.6: New ascending "^" and descending "v" indicators for inclination, also some minor fixes and formatting changes
  - 0.7: Fixed bug with volume key always activating mute if game started at vol level 0
  - 0.8: Fixed bug with Warp to Node; Added "Warp to Ap/Pe" if no Node; Changed default for Ascent Guidance; Minor formatting changes; undocumented "SpecialData" (see cfg)


# DESCRIPTION:

We all do it: You're launching a glorious new rocket, and you have to constantly flip between the Map view and Ship view, so you can track the __Apoapsis__ and __Periapsis__ during ascent.
I'd rather watch my rocket and epic staging events than a parabola line. Even worse, right-click the Apoapsis to keep the data visible > then switch back to Ship view > switch back to Map view and *poof* the data is gone again. Repeat.

As you probably know, mods like *Kerbal Engineer*, *MechJeb*, *VOID*, and *BasicOrbit* can already show this information and a lot more, but I wanted something minimalist and simpler. Preferably, a single file plug-in (with minimum-to-no dependencies), and a basic .cfg text file that I can easily edit for changes.

Using this mod, I can get perfectly circular orbits every time, and at the precise desired altitude, all without ever needing to go into Map view.
It's very satisfying to reach a perfect orbit by hand-flying with this tool.

Next, during the ascent, there are numerous changes typically made with SAS relating to switching pointing reference -- Surface while low, and Orbit when higher. In the stock configuration, this requires mouse moves/clicks to activate. Sometimes you need  to switch really quickly, and fishing with the mouse is not easy on 1440p or 4K screens. To facilitate SAS changes, this mod lets you map keys for Prograde and Retrograde pointing, and also key toggling for the SAS Mode ("Current Plane of Reference"), between __SAS: Surface__ and __SAS: Orbit__.

Since we're mapping commands here, we've all had the experience of trying to click the (nearly hidden) dotted brown line so you can pick __Warp to Next Maneuver__.
As you know, when the Maneuver trajectory is too close to the current trajectory, it's nearly impossible to right-click it with the mouse.
With this mod, you can assign the __Warp To Node__ command to any unused key.
Even better, you can set the time allowance to be anything you want, instead of the default 60 seconds that exists in KSP version 1.5.1 and lower.
Using this key command also sets the pointing to SAS:Maneuver, which is one less thing you have to click.
__New for Version 0.8__: If there is no Maneuver Node, then this will warp you to the next Apoapsis/Periapsis minus 30 seconds - great for orbital circularization!

Finally, I also threw in keyboard access for __Mute__, which is normally only available in the popup Settings.
So now you can listen to that wonderful orbital harp music when you want, and turn it off before that Munar suicide burn gets tense, and without needing to change the main computer volume.

The key bindings are displayed at the bottom of the Telemetria window, but you can change this behavior to hidden by editing the .cfg file (instructions below).

display option = 0 (show all key bindings at bottom)  

![](https://i.imgur.com/0ZCYlFa.png)

display option = 1 (show truncated key bindings in title bar)  

![](https://i.imgur.com/YFqLhLU.png)

display option = 2 (hide key bindings)  

![](https://i.imgur.com/PtGgEgn.png)

#### Feature: Ascent Guidance
"Ascent Guidance" shows you the optimum pitch angle to steer while climbing to arrive at your desired altitude and angle.
If you've played KSP for awhile, you probably already do this based on instinct, however this guidance can assist you with achieving a Kerbal Space Agency-approved launch trajectory resulting in a circular orbit with minimum fuel.
The formula used for guidance was listed in this thread:

[https://www.reddit.com/r/KerbalAcademy/comments/4b878r/how_to_launch_rockets_efficiently_in_ksp_105_and/](https://www.reddit.com/r/KerbalAcademy/comments/4b878r/how_to_launch_rockets_efficiently_in_ksp_105_and/)

Ascent Guidance will be active if the following conditions are true:
1) The .cfg file key "*Ascent Show Guidance*" is set (see below about .cfg file entries);
2) You are launching from a location with an atmosphere (non-atmospheric launches do not need guidance, and should turn prograde immediately after rising above terrain height)
3) The vertical speed is currently higher than 20m/s
4) You are above the "Start Turn" altitude in the .cfg file

The following parameters are available to tweak your ascent trajectory: (a) Launch thrust-to-weight ratio TWR, use "1.5" if you are unsure, (b) Start Turn Altitude, (c) End Turn Altitude, (d) End Turn Pitch Angle.
Telemetria can pick all of these parameters for you with default values, which should work for both Kerbin and Earth/RSS.

__Feature: Latitude__ shows the current latitude degrees, plus time to the next 0 node (when you cross a plane of reference such as the equator, in other words the next Ascending (AN) or Descending (DN) node). The 0 transition happens twice per orbit.
The *"time to 0"* is helpful since it allows you to adjust your inclination at a celestial body using no other references.
This means you don't need to do the trick of "put a probe orbiting at 0" (or hyperedit the *persistent.sfs* file) to obtain a reference for inclination changes.
Like most data that Telemetria provides, the current Latitude and time to AN/DN is not available on the stock KSP ship screen, but is critical for realistic orbital flight ops.

__Feature: Inclination Indicator__ Added small indicators to show if you are heading up "^" or down "v" on inclination.
Note that this is independent of current latitude; "going up" can be positive or negative latitude.
This information helps you to know which way to point (Normal or Antinormal) for inclination changes when reaching the 0 transition.

![](https://i.imgur.com/x8PoZfm.png)      ![](https://i.imgur.com/Huf7vOC.png)


# INSTALLATION / COMPATIBILITY / DEPENDENCIES:

- Like all Kerbal Space Program system-level mods, the free *"ModuleManager"* is required (all MM versions 3.x/4.x tested fine with this mod). If you have any other mods, you already have MM in your GameData folder.

- copy "Telemetria.dll" and "Telemetria.cfg" to "[KSP install folder]\GameData\Telemetria", so the file structure looks like this:
        
        \Kerbal Space Program\GameData\Telemetria\
                                                  Telemetria.cfg
                                                  Telemetria.dll

Tested with:

[x] KSP 1.7.1

[x] KSP 1.6.1

[x] KSP 1.5.1

[x] KSP 1.3.1

[x] ModuleManager 3.0.4, 3.1.2, 3.1.3, 4.0.2, etc.

(Probably works with other versions, too.)

# CONFIG FILE REFERENCE:    

Everything about Telemetria is controlled by the settings (text) file "Telemetria.cfg". 
As of v0.4, you can even change the .cfg file entries while playing the game, and Telemetria tries to be intelligent about your new settings without requiring a KSP restart 
(it will reload changes during a scene or vessel switch). 
This allows you make changes based on new ships and launches, or alternate target orbits, without restarting.

You can delete the "Telemetria.cfg" file, and a canned template (default) settings file will be created for you.

Telemetria saves the (x,y) coordinates of its app window to the config file. This means the Telemetria window is persistent between KSP sessions.
All the other settings are meant to be manually modified with a text editor like Notepad (I have no plans to make a special UI for this mod, and in KSP you quickly get skilled at modifying .cfg files).


// Key Examples:    Y, F6, PageUp, ScrollLock, Keypad5, KeypadEnter, Mouse2, JoystickButton0, etc.

// Full Key List:   https://docs.unity3d.com/ScriptReference/KeyCode.html

// Avoid conflicts: https://wiki.kerbalspaceprogram.com/wiki/Key_bindings

    window_x = 0                    // Window position Left (this is automatically updated by Telemetria)
    window_y = 0                    // Window position Top (this is automatically updated by Telemetria)
    warp_node_margin = 120          // Time, in seconds, of the "Warp to Next Maneuver" buffer
    display_options = 0             // 0=Show key bindings at bottom, 1=Show key bindings in title bar, 2=Do not show key bindings
	
    ascent_show_guidance = true     // Display "Estimated Pitch Angle for Optimum Ascent" for atmospheric launches
    ascent_launch_TWR    = 1.5      // Thrust-to-weight ratio at launch (default: 1.5)
    ascent_turn_start    = 500      // Altitude to begin gravity turn (default: 500m)
    ascent_turn_end      = 70000    // Altitude to end guidance (default: atmosphere height * 1.2, which is 84,000m for Kerbin, or 168,000 for Earth, naturally the full gravity turn may continue much higher.)
    ascent_angle_final   = 0        // Pitch angle when guidance is complete (default: 5.0; a non-zero angle aids in following Prograde marker the rest of the way to orbit)
	
    Prograde = KeypadDivide         // Activates "Prograde" following in SAS mode
    Retrograde = KeypadMultiply     // Activates "Retrograde" following in SAS mode
    SASMode = Y                     // Toggles between "Surface" and "Orbit" mode for SAS
    Mute = F7                       // Master mute toggle for all KSP sounds
    WarpToNode = KeypadEnter        // Provides "Warp to Next Maneuver" without needing to right-click mouse
    Hide_Toggle = F6                // Show/Hide the Telemetria window


# Known Bugs:
- When you press F2 to hide all screen elements, and Telemetria is already hidden, it will reappear (you can hide Telemetria again with F6 or whatever your key binding is).  
I haven't found a good reliable way in the game mechanics to recognize when other screen objects are hidden... maybe some other mod has figured this out and I need to research more.  
Sorry for any inconvenience this causes. I'll fix it eventually.
  

# FAQ:
*(well actually nobody has asked any of these questions, but I would ask them myself, and I'm trying to anticipate quesitons and give answers)*
  

#### *1) Why is it named Telemetria*
    
    Since this mod primarily deals with telemetry from the Launch and Ascent phases of flight, *Telemetria* was the obvious name choice.
    (and btw Telemetria is Spanish for telemetry, pero con acento por supuesto)
  
  

#### *2) Why no "SAS:Target" toggle?*
    
    Because I made this mostly for ascents. Plus, when doing an orbital rendezvous, you typically click the "Target" mode approximately one time and just leave it on.
    So it didn't seem like it needed quick access.
    I can certainly add it if people request it, BUT then you will have to cycle through 3 modes instead of 2.
  
  
#### *3) Why no "Toggle SAS on/off"*
    
    The stock game already does that with "T"
  
  
#### *4) Will you add other commands for keyboard mapping?*
    
    Maybe, if it makes sense and others want it too. But I'd prefer to keep this simple and small.
  
  
#### *5) If this functionality already exists in mods like KER and MechJeb, why did you create a new mod?*
    
	I wrote this primarily to solve the few things that I found annoying in the stock game to make my life easier, but without all the complexity, overhead, and dependencies of a major add-on.
	I'm not aware of any mod that provides these specific features (Ap/Pe, Guidance, key override for Surface/Orbit), and nothing else, all displayed in the same tiny window.
	Plus, this project gave me the experience of writing a mod for a popular game, using my own source code that I can update instantly for new versions.
	Hopefully you find this mod useful like I do.